Index: environs/tools.go |
=== modified file 'environs/tools.go' |
--- environs/tools.go 2013-04-17 05:14:05 +0000 |
+++ environs/tools.go 2013-04-17 06:39:43 +0000 |
@@ -129,13 +129,13 @@ |
return list, err |
} |
// EnsureAgentVersion returns a ToolsList containing only those tools with |
// which it would be reasonable to launch an environment's first machine, |
// given the supplied constraints. |
// If the environment was not already configured to use a specific agent |
// version, the newest available version will be chosen and set in the |
// environment's configuration. |
-func EnsureAgentVersion(environ Environ, cons constraints.Value) (list tools.List, err error) { |
+func FindBootstrapTools(environ Environ, cons constraints.Value) (list tools.List, err error) { |
defer convertToolsError(&err) |
// Collect all possible compatible tools. |
cliVersion := version.Current.Number |
@@ -129,13 +129,13 @@ |
return list, err |
} |
-// EnsureAgentVersion returns a ToolsList containing only those tools with |
+// FindBootstrapTools returns a ToolsList containing only those tools with |
// which it would be reasonable to launch an environment's first machine, |
// given the supplied constraints. |